@@ -41,12 +41,12 @@ PosInfo::PosInfo( const double  lat, const double lon, const double alt, const Q
     DateTime = FormatDateTime(tim);
 }
 
-void MainWindow::AddButton(const QString Titel, const int Id, const int x, const int y)
+void MainWindow::AddButton(const QString Titel, const int Id, const int idx)
 {
     QPushButton *pbOther =new QPushButton(Titel);
     signalMapper->setMapping(pbOther, Id);
     connect(pbOther, SIGNAL(clicked()), signalMapper, SLOT(map()));
-    ui->gridLayout->addWidget(pbOther,x,y);
+    ui->gridLayout->addWidget(pbOther,idx / Bpl,idx % Bpl);
 }
 
 void MainWindow::BuildButtons()
@@ -60,8 +60,8 @@ void MainWindow::BuildButtons()
 
     int i;
     for (i=0; i<Buttons.count(); i++)
-        AddButton(Buttons[i],i,i / Bpl,i % Bpl);
-    AddButton("Other",9999,i / 5,i % 5);
+        AddButton(Buttons[i],i,i);// / Bpl,i % Bpl);
+    AddButton("Other",9999,i);// / Bpl,i % Bpl);
 }
 
 MainWindow::MainWindow(QWidget *parent) :
@@ -272,7 +272,7 @@ void MainWindow::WriteConfig()
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::information ( this, tr("OSMapper"),
-                                 tr("OSMapper v.4.0\nCopyright Kim Foder 2010\n\nHomepage : http://osmapper.garage.maemo.org/"));
+                                 tr("OSMapper v.1.4.1\nCopyright Kim Foder 2010\n\nHomepage : http://osmapper.garage.maemo.org/"));
 }
 
 void MainWindow::pushButton_clicked(int id)
