@@ -35,7 +35,7 @@ class WayInfo
        QString WayPointType;
    };
 
-#define OSMVersion = "4.0"
+//#define OSMVersion = "4.0"
 
 class MainWindow : public QMainWindow
 {
@@ -86,7 +86,7 @@ private:
     void ExportTrack();
     void ReadConfig();
     void WriteConfig();
-    void AddButton(const QString Titel, const int Id, const int x, const int y);
+    void AddButton(const QString Titel, const int Id, const int idx);//, const int y);
 
 };
 
